Python API
==========

``datalad-osf`` has two main commands that are exposed as functions via ``datalad.api`` and as methods of the ``Dataset`` class: ``osf_credentials`` for OSF authentication management, and ``create_sibling_osf`` for interactions with the OSF.
Find out more about each command below.

.. currentmodule:: datalad.api
.. autosummary::
   :toctree: generated

   osf_credentials
   create_sibling_osf